/*
 * Licensed Materials - Property of IBM
 * 5725-G92 (C) Copyright IBM Corp. 2012, 2013. All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
/*
 *	This piece of code was added as a part of upgrading your application 
 *	to a new authentication API introduced in Worklight 5.0.0.3
 *		
 *	Authenticator object that was used previosly is deprecated.
 *	New challenge handler APIs are serving as a wrapper for original Authenticator object.
 *	To learn more about challenge handler APIs please refer to Worklight documentation.
 *
 */

// ----------------- Challenge handler start -----------------
var challengeHandler1 = WL.Client.createChallengeHandler("realm1");

challengeHandler1.isInitialized = false;
challengeHandler1.isCustomResponse = function(response) {
    if (typeof Authenticator == "undefined") {
        return false;
    }

    if (!this.isInitialized) {
        this.isInitialized = true;
        Authenticator.init();
    }

    var isLoginFormResponse = Authenticator.isLoginFormResponse(response);
    if (isLoginFormResponse) {
        Authenticator.onBeforeLogin(response, null, challengeHandler1.onSubmitButtonClicked);
        Authenticator.onShowLogin();
    } else {
        Authenticator.onHideLogin();
    }
    return isLoginFormResponse;
};

challengeHandler1.onSubmitButtonClicked = function(reqURL, authParams) {
    var options = {
        headers : {},
        parameters : (authParams && authParams.parameters) ? authParams.parameters : {}
    };

    challengeHandler1.submitLoginForm(reqURL, options, challengeHandler1.submitLoginFormCallback);
};

challengeHandler1.submitLoginFormCallback = function(response) {
    var isLoginFormResponse = challengeHandler1.isCustomResponse(response);
    if (!isLoginFormResponse) {
        challengeHandler1.submitSuccess();
    }
};
// ----------------- Challenge handler end -----------------

window.busy = new WL.BusyIndicator('content', { duration: 1 });

function openCacheFailure(status) {
	WL.Logger.debug('Open Encrypted Cache failed: ' + status);
	busy.hide();
}
function writeEncCache(key, value, onSuccess) {
	busy.show();
	WL.EncryptedCache.open('ENCRYPT_KEY', true, function(status) {
		WL.EncryptedCache.write(key, value, function() {
			if($.isFunction(onSuccess)) {
				onSuccess();
			}
			WL.EncryptedCache.close();
			busy.hide();
		}, function(status) {
			alert("Write Encrypted Cache failed. error code= " + status);
		});
	}, openCacheFailure);
}
function readEncCache(key, onSuccess) {
	busy.show();
	WL.EncryptedCache.open('ENCRYPT_KEY', true, function(status) {
		// if in offline mode, check username and password from Encrypted Cache
		WL.EncryptedCache.read(key, function(value) {
			if($.isFunction(onSuccess)) {
				onSuccess(value);
			}
			WL.EncryptedCache.close();
			busy.hide();
		}, function(status) {
			alert("Read Encrypted Cache failed. error code= " + status);
		});
	}, openCacheFailure);
}

window.doLogin = function(username, password) {
//	var USERNAME_INPUT_ID = '#username';
//	var PASSWORD_INPUT_ID = '#password';
	
//	var username = $(USERNAME_INPUT_ID).val();
//	var password = $(PASSWORD_INPUT_ID).val();
	
	if(!username || !password) {
		alert("Username and password cannot be empty!");
        return;
	}
	
	WL.Device.getNetworkInfo(function(netInfo) {
		var isNetworkConnected = (netInfo.isNetworkConnected == 'true');
		function loginSuccess() {
			window.ft.userId = username;
			var nextPage = window.ft.nextPage || $('#mainPage');
			jq.mobile.changePage(nextPage);
			window.ft.nextPage = '';
			if(isNetworkConnected) {
				connectDetected();
			}
		};
		if(!isNetworkConnected || window.ft.usersLoginToServer[username]) {
			readEncCache(username, function(cachedPassword) {
				if(password != cachedPassword) {
					alert('Invalid username or password!');
				} else {
					loginSuccess();
				}
			});
		} else {
			var invocationData = {
				adapter : "FTAdapter",
				procedure : "login",
				parameters : [ username, password ]
			};
			WL.Client.invokeProcedure(invocationData, {
				onSuccess: function(resp) {
					window.ft.usersLoginToServer[username] = true;
					writeEncCache(username, password);
					loginSuccess();
				},
				onFailure: function(resp) {
					console.log("invoke FTAdapter failed: " + resp);
				}
			});
		}
	});
};

var Authenticator = function () {
	return {
		init : function() {
		},

		isLoginFormResponse : function(response) {
			if (!response || !response.responseJSON	|| response.responseText === null) {
				return false;
			}
			return response.responseJSON.authRequired;
		},

		onBeforeLogin : function(response, username, onSubmit, onCancel) {
			if (response.responseJSON && response.responseJSON.errorMessage) {
				alert(response.responseJSON.errorMessage);
			}
		},

		onShowLogin : function() {
//			$.mobile.hidePageLoadingMsg();
//			$.mobile.changePage(jq('#loginView'));
		},

		onHideLogin : function() {
//			$.mobile.hidePageLoadingMsg();
		}
	};
}();
